powered by
Return indices of data that were not fitted by the model.
missing_est(model)
The indices of the data that were not fitted by the model.
A fitted regression model (using lm, glm, gam, or bam).
Jacolien van Rij
Other Utility functions: convertNonAlphanumeric(), corfit(), diff_terms(), find_difference(), modeledf(), observations(), print_summary(), refLevels(), res_df(), summary_data(), timeBins()
convertNonAlphanumeric()
corfit()
diff_terms()
find_difference()
modeledf()
observations()
print_summary()
refLevels()
res_df()
summary_data()
timeBins()
data(simdat) # Add missing values: set.seed(123) simdat[sample(nrow(simdat), size=20),]$Y <- NA # Fit simple linear model: lm1 <- lm(Y ~ Time, data=simdat) na.el <- missing_est(lm1) length(na.el)
Run the code above in your browser using DataLab