Learn R Programming

itsadug (version 2.5)

modeledf: Retrieve the degrees of freedom specified in the model.

Description

Retrieve the degrees of freedom specified in the model.

Usage

modeledf(model)

Value

Numeric value: degrees of freedom specified in the model.

Arguments

model

A fitted regression model (using gam, or bam).

See Also

Other Utility functions: convertNonAlphanumeric(), corfit(), diff_terms(), find_difference(), missing_est(), observations(), print_summary(), refLevels(), res_df(), summary_data(), timeBins()