Visualization of EEG topo maps.
plot_topo(
model,
view,
el.pos = NULL,
fun = "fvisgam",
add.color.legend = TRUE,
size = 5,
n.grid = 100,
col = 1,
pch = 21,
bg = alpha(1),
color = "bwr",
xlab = "",
ylab = "",
setmargins = TRUE,
...
)
A two-value vector containing the names of the two main effect terms to be displayed on the x and y dimensions of the plot. Note that variables coerced to factors in the model formula won't work as view variables.
A list with X and Y positions and Electrodes, which are used for fitting the model.
Text string, 'fvisgam', 'pvisgam', or 'plot_diff2' signalling which function to use for plotting.
Logical: whether or not to add a color legend.
Default is TRUE. If FALSE (omitted), one could use the function
gradientLegend to add a legend manually at any position.
Size in inch of plot window.
The number of grid nodes in each direction used for calculating the plotted surface.
The colors for the background of the plot.
The type of points as indications for the electrode positions. The value NA will suppress the plotting of electrode positions.
The background color of the points.
The color scheme to use for plots. One of 'topo', 'heat', 'cm', 'terrain', 'gray', 'bw', or 'rwb' (red-white-blue; default).
Label x-axis. Default excluded.
Label y-axis. Default excluded.
Logical: whether or not to automatically set the margins. By default set to TRUE. If set to false, the size can
other options to pass on to fvisgam,
pvisgam, or plot_diff2.
X-positions of electrodes should have lower values for electrodes on the left hemisphere (e.g. T7) than for electrodes on the right hemisphere. Y-positions of electrodes should have lower values for electrodes at the back of the head than for the frontal electrodes.
Jacolien van Rij
Other Functions for model inspection:
dispersion(),
fvisgam(),
gamtabs(),
inspect_random(),
plot_data(),
plot_parametric(),
plot_smooth(),
pvisgam()