Learn R Programming

itsadug (version 2.5)

report_stats: Returns a description of the statistics of the smooth terms for reporting.

Description

Returns a description of the statistics of the smooth terms for reporting.

Usage

report_stats(model, summary = NULL, print.summary = getOption("itsadug_print"))

Arguments

model

A gam or bam object, produced by gam or bam.

summary

Optionally include the summary of the model when available, which may speed up the process for large models.

print.summary

Logical: whether or not to print the output. Default set to the print info messages option (see infoMessages).

Author

Jacolien van Rij

See Also

Other Testing for significance: compareML(), plot_diff(), plot_diff2(), wald_gam()

Examples

Run this code
data(simdat)

# model without random effects:
m1 <- bam(Y ~ te(Time, Trial), data=simdat)
report_stats(m1)
# save report for later use:
report <- report_stats(m1, print.summary=FALSE)
report[3,2]

Run the code above in your browser using DataLab