powered by
Returns a description of the statistics of the smooth terms for reporting.
report_stats(model, summary = NULL, print.summary = getOption("itsadug_print"))
A gam or bam object, produced by gam or bam.
gam
bam
Optionally include the summary of the model when available, which may speed up the process for large models.
Logical: whether or not to print the output. Default set to the print info messages option (see infoMessages).
infoMessages
Jacolien van Rij
Other Testing for significance: compareML(), plot_diff(), plot_diff2(), wald_gam()
compareML()
plot_diff()
plot_diff2()
wald_gam()
data(simdat) # model without random effects: m1 <- bam(Y ~ te(Time, Trial), data=simdat) report_stats(m1) # save report for later use: report <- report_stats(m1, print.summary=FALSE) report[3,2]
Run the code above in your browser using DataLab